==> primefaces-11.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-sv.js <==
/** Swedish */
PrimeFaces.locales['sv'] = {
    closeText: 'Stäng',
    prevText: 'Föregående',
    nextText: 'Nästa',
    monthNames: ['januari', 'februari', 'mars', 'april', 'maj', 'juni', 'juli', 'augusti', 'september', 'oktober', 'november', 'december'],
    monthNamesShort: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
    dayNames: ['söndag', 'måndag', 'tisdag', 'onsdag', 'torsdag', 'fredag', 'lördag'],
    dayNamesShort: ['sön', 'mån', 'tis', 'ons', 'tor', 'fre', 'lör'],
    dayNamesMin: ['sö', 'må', 'ti', 'on', 'to', 'fr', 'lö'],
    weekHeader: 'Vecka',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Endast tid',
    timeText: 'Tid',
    hourText: 'timmar',
    minuteText: 'minuter',
    secondText: 'sekunder',
    millisecondText: 'millisekunder',
    currentText: 'Nuvarande datum',
    ampm: false,
    month: 'månad',
    week: 'vecka',
    day: 'dag',
    allDayText: 'Hela dagen',
    messages: {
        'javax.faces.component.UIInput.REQUIRED': '{0}: Valideringsfel: Värde är obligatoriskt.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\'måste vara ett numeriskt värde mellan -2147483648 och 2147483647 Example: {1}',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 4.9E-324 and 1.7976931348623157E308  Example: {1}',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' måste vara numeriskt.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' måste vara numeriskt bestående av en eller flera siffror eller decimaler. Example: {1}',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror. Example: {1}',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 0 and 255.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 0 and 255.  Example: {1}',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' måste vara ett giltligt tecken.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' måste vara ett giltligt ASCII tecken.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan -32768 and 32767 Example: {1}',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' måste vara \'sant\' eller \'falskt\'',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' måste vara \'sant\' eller \'falskt\'.  Any value other than \'true\' will evaluate to \'false\'.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Valideringsfel: Värdet är större än tillåtna värdet av\'{0}\'',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Valideringsfel: Värdet är mindre än tillåtna värdet av \'{0}\'',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Valideringsfel: Det specifika attributet är inte mellan de förväntade värdena {0} och {1}.',
        'javax.faces.validator.LongRangeValidator.TYPE={0}': 'Valideringsfel: Värdet är av felaktig typ.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Valideringsfel: Värdet är större än det tillåtna värdet av \'{0}\'',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Valideringsfel: Värdet är mindre än tillåtna värdet av \'{0}\'',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Valideringsfel: Det specifika attributet är inte mellan de förväntade värdena {0} och {1}',
        'javax.faces.validator.DoubleRangeValidator.TYPE={0}': 'Valideringsfel: Värdet är inte av korrekt typ',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror. ',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 1.4E-45 och 3.4028235E38  Example: {1}',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' felaktigt datumformat.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\' felaktigt datumformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' felaktigt tidsformat.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' felaktigt tidsformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' felaktigt datum- och tidsformat.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' felaktigt datum- och tidsformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: Ett \'format\' eller \'en typ\' av attribut must definieras för att konvertera värdet. \'{0}\'',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' är inte ett format för valuta.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' är inte ett format för valuta. Example: {1}',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' är inte ett procentuellt värde.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' är inte ett procentuellt värde. Example: {1}',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' felaktigt datumformat.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' är inte en siffra. Example: {1}',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' är inte ett numeriskt format.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' är inte ett numeriskt format. Example: {1}',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Valideringsfel: Längden är kortare än lägsta tillåtna värde \'{0}\'',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Valideringsfel: Längden är längre än högsta tillåtna värde \'{0}\'',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Ett format måste definnieras.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Ett format måste definieras för att kräva ett värde.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Formatet är inte korrekt',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': 'Formatet för \'{0}\' är inte korrekt.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Fel i reguljära uttryck.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Fel i reguljära uttryck, \'{0}\''
    }
};

==> primefaces-13.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-sv.js <==
/** Swedish */
PrimeFaces.locales['sv'] = {
    closeText: 'Stäng',
    prevText: 'Föregående',
    nextText: 'Nästa',
    monthNames: ['januari', 'februari', 'mars', 'april', 'maj', 'juni', 'juli', 'augusti', 'september', 'oktober', 'november', 'december'],
    monthNamesShort: ['jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec'],
    dayNames: ['söndag', 'måndag', 'tisdag', 'onsdag', 'torsdag', 'fredag', 'lördag'],
    dayNamesShort: ['sön', 'mån', 'tis', 'ons', 'tor', 'fre', 'lör'],
    dayNamesMin: ['sö', 'må', 'ti', 'on', 'to', 'fr', 'lö'],
    weekHeader: 'Vecka',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Endast tid',
    timeText: 'Tid',
    hourText: 'timmar',
    minuteText: 'minuter',
    secondText: 'sekunder',
    millisecondText: 'millisekunder',
    currentText: 'Nuvarande datum',
    ampm: false,
    month: 'månad',
    week: 'vecka',
    day: 'dag',
    allDayText: 'Hela dagen',
    clear: 'Återställa',
    messages: {
        'javax.faces.component.UIInput.REQUIRED': '{0}: Valideringsfel: Värde är obligatoriskt.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\'måste vara ett numeriskt värde mellan -2147483648 och 2147483647 Example: {1}',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 4.9E-324 and 1.7976931348623157E308  Example: {1}',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' måste vara numeriskt.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' måste vara numeriskt bestående av en eller flera siffror eller decimaler. Example: {1}',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror. Example: {1}',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 0 and 255.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 0 and 255.  Example: {1}',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' måste vara ett giltligt tecken.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' måste vara ett giltligt ASCII tecken.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan -32768 and 32767 Example: {1}',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' måste vara \'sant\' eller \'falskt\'',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' måste vara \'sant\' eller \'falskt\'.  Any value other than \'true\' will evaluate to \'false\'.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Valideringsfel: Värdet är större än tillåtna värdet av\'{0}\'',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Valideringsfel: Värdet är mindre än tillåtna värdet av \'{0}\'',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Valideringsfel: Det specifika attributet är inte mellan de förväntade värdena {0} och {1}.',
        'javax.faces.validator.LongRangeValidator.TYPE': '{0}: Valideringsfel: Värdet är av felaktig typ.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Valideringsfel: Värdet är större än det tillåtna värdet av \'{0}\'',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Valideringsfel: Värdet är mindre än tillåtna värdet av \'{0}\'',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Valideringsfel: Det specifika attributet är inte mellan de förväntade värdena {0} och {1}',
        'javax.faces.validator.DoubleRangeValidator.TYPE': '{0}: Valideringsfel: Värdet är inte av korrekt typ',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' måste vara ett numeriskt värde bestående av 1 eller flera siffror. ',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' måste vara ett numeriskt värde mellan 1.4E-45 och 3.4028235E38  Example: {1}',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' felaktigt datumformat.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\' felaktigt datumformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' felaktigt tidsformat.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' felaktigt tidsformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' felaktigt datum- och tidsformat.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' felaktigt datum- och tidsformat. Example: {1}',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: Ett \'format\' eller \'en typ\' av attribut must definieras för att konvertera värdet. \'{0}\'',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' är inte ett format för valuta.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' är inte ett format för valuta. Example: {1}',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' är inte ett procentuellt värde.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' är inte ett procentuellt värde. Example: {1}',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' felaktigt datumformat.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' är inte en siffra. Example: {1}',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' är inte ett numeriskt format.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' är inte ett numeriskt format. Example: {1}',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Valideringsfel: Längden är kortare än lägsta tillåtna värde \'{0}\'',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Valideringsfel: Längden är längre än högsta tillåtna värde \'{0}\'',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Ett format måste definnieras.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Ett format måste definieras för att kräva ett värde.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Formatet är inte korrekt',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': 'Formatet för \'{0}\' är inte korrekt.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Fel i reguljära uttryck.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Fel i reguljära uttryck, \'{0}\''
    }
};
